==> easy-antd-modal-1.1.1.tgz: package/es/hooks/useModalEnhanced.js <==
function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }
function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }
function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }
function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i]; return arr2; }
function _iterableToArrayLimit(arr, i) { var _i = null == arr ? null : "undefined" != typeof Symbol && arr[Symbol.iterator] || arr["@@iterator"]; if (null != _i) { var _s, _e, _x, _r, _arr = [], _n = !0, _d = !1; try { if (_x = (_i = _i.call(arr)).next, 0 === i) { if (Object(_i) !== _i) return; _n = !1; } else for (; !(_n = (_s = _x.call(_i)).done) && (_arr.push(_s.value), _arr.length !== i); _n = !0); } catch (err) { _d = !0, _e = err; } finally { try { if (!_n && null != _i.return && (_r = _i.return(), Object(_r) !== _r)) return; } finally { if (_d) throw _e; } } return _arr; } }
function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }
import React from 'react';
import { useEasyAntdModalContext } from "../context";
import { isDOMTypeElement, isElement, omit } from "../util";
import useBoolean from "./useBoolean";

// eslint-disable-next-line @typescript-eslint/ban-types

function useModalEnhanced() {
  var props = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  var onClick = props.onClick,
    actionRefProp = props.actionRef,
    defaultOpen = props.defaultOpen;
  var _useBoolean = useBoolean(defaultOpen),
    _useBoolean2 = _slicedToArray(_useBoolean, 2),
    visible = _useBoolean2[0],
    _useBoolean2$ = _useBoolean2[1],
    open = _useBoolean2$.setTrue,
    close = _useBoolean2$.setFalse;
  var actionRef = React.useRef({
    open: open,
    close: close
  });
  var _useEasyAntdModalCont = useEasyAntdModalContext(),
    triggerProps = _useEasyAntdModalCont.triggerProps,
    contentProps = _useEasyAntdModalCont.contentProps;
  var mergedTrigger = props[triggerProps];
  var mergedContent = props[contentProps];
  React.useImperativeHandle(actionRefProp, function () {
    return actionRef.current;
  });
  var handleClick = function handleClick(event) {
    if (onClick) return onClick(event, actionRef.current);
    return open();
  };

  // ======================== Trigger ========================
  var trigger = mergedTrigger;
  if ( /*#__PURE__*/React.isValidElement(mergedTrigger)) trigger = /*#__PURE__*/React.cloneElement(mergedTrigger, {
    onClick: handleClick
  });

  // ======================== Content ========================
  var contentNode = mergedContent;
  if (isElement(contentNode) && !isDOMTypeElement(contentNode)) {
    contentNode = /*#__PURE__*/React.cloneElement(contentNode, {
      enhancedAction: actionRef.current
    });
  } else if (typeof mergedContent === 'function') {
    contentNode = mergedContent({
      enhancedAction: actionRef.current
    });
  }
  var contextHolder = {
    trigger: trigger,
    content: contentNode
  };
  var action = {
    open: open,
    close: close
  };
  var resetProps = omit(props, ['defaultOpen', 'onClick', 'actionRef', 'content', 'trigger', 'children']);
  return [visible, action, contextHolder, resetProps];
}
export default useModalEnhanced;

==> easy-antd-modal-1.4.0.tgz: package/es/hooks/useModalEnhanced.js <==
function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }
function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }
function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }
function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i]; return arr2; }
function _iterableToArrayLimit(arr, i) { var _i = null == arr ? null : "undefined" != typeof Symbol && arr[Symbol.iterator] || arr["@@iterator"]; if (null != _i) { var _s, _e, _x, _r, _arr = [], _n = !0, _d = !1; try { if (_x = (_i = _i.call(arr)).next, 0 === i) { if (Object(_i) !== _i) return; _n = !1; } else for (; !(_n = (_s = _x.call(_i)).done) && (_arr.push(_s.value), _arr.length !== i); _n = !0); } catch (err) { _d = !0, _e = err; } finally { try { if (!_n && null != _i.return && (_r = _i.return(), Object(_r) !== _r)) return; } finally { if (_d) throw _e; } } return _arr; } }
function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }
import React from 'react';
import { useEasyAntdModal } from "../context";
import { isDOMTypeElement, isElement, omit } from "../util";
import useBoolean from "./useBoolean";

// eslint-disable-next-line @typescript-eslint/ban-types

function useModalEnhanced() {
  var props = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  var onClick = props.onClick,
    actionRefProp = props.actionRef,
    defaultOpen = props.defaultOpen;
  var _useBoolean = useBoolean(defaultOpen),
    _useBoolean2 = _slicedToArray(_useBoolean, 2),
    visible = _useBoolean2[0],
    _useBoolean2$ = _useBoolean2[1],
    open = _useBoolean2$.setTrue,
    close = _useBoolean2$.setFalse;
  var actionRef = React.useRef({
    open: open,
    close: close
  });
  var _useEasyAntdModal = useEasyAntdModal(),
    triggerProps = _useEasyAntdModal.triggerProps,
    contentProps = _useEasyAntdModal.contentProps;
  var mergedTrigger = props[triggerProps];
  var mergedContent = props[contentProps];
  React.useImperativeHandle(actionRefProp, function () {
    return actionRef.current;
  });
  var handleClick = function handleClick(event) {
    if (onClick) return onClick(event, actionRef.current);
    return open();
  };

  // ======================== Trigger ========================
  var trigger = mergedTrigger;
  if ( /*#__PURE__*/React.isValidElement(mergedTrigger)) trigger = /*#__PURE__*/React.cloneElement(mergedTrigger, {
    onClick: handleClick
  });

  // ======================== Content ========================
  var contentNode = mergedContent;
  if (isElement(contentNode) && !isDOMTypeElement(contentNode)) {
    contentNode = /*#__PURE__*/React.cloneElement(contentNode, {
      enhancedAction: actionRef.current
    });
  } else if (typeof mergedContent === 'function') {
    contentNode = mergedContent({
      enhancedAction: actionRef.current
    });
  }
  var contextHolder = {
    trigger: trigger,
    content: contentNode
  };
  var action = {
    open: open,
    close: close
  };
  var resetProps = omit(props, ['defaultOpen', 'onClick', 'actionRef', 'content', 'trigger', 'children']);
  return [visible, action, contextHolder, resetProps];
}
export default useModalEnhanced;
